@@ -32,7 +32,7 @@ def hpc_mafft(path_input, path_output, cores=1, high_accuracy_method=None):
                 "{} high_accuracy_method argument should be: \"localpair\", \"genafpair\" or \"globalpair\".")
 
         cmd = ("""
-module load singularity/3.8.3 &&
+module load singularity/3.8.3 &
 singularity exec /softs/applications/containers/mafft/mafft_7.307_v1.0.simg mafft --{} --thread {} --quiet {} > {}
 """
                ).format(high_accuracy_method,
@@ -41,7 +41,7 @@ singularity exec /softs/applications/containers/mafft/mafft_7.307_v1.0.simg maff
                         path_output)
     else:
         cmd = ("""
-module load singularity/3.8.3 &&
+module load singularity/3.8.3 &
 singularity exec /softs/applications/containers/mafft/mafft_7.307_v1.0.simg mafft --thread {} --quiet {} > {}
 """
                ).format(cores, path_input, path_output)
@@ -73,7 +73,7 @@ def hpc_tcoffee(path_input, path_output, seq_type="dna", pairwise=False, debug=F
                          "correct values are \"dna\", \"rna\" or \"protein\".\n".format(seq_type))
     # set the command line
     cmd = ("""
-module load singularity/3.8.3 &&
+module load singularity/3.8.3 &
 singularity exec /softs/applications/containers/t_coffee/tcoffee_13.39.0_v1.0.simg t_coffee -in=S{} -outfile {} -type {}
 """
            ).format(path_input, path_output, seq_type)
@@ -109,5 +109,5 @@ def __run_alignment(command):
         if process.poll() is not None:
             break
     if process.poll() != 0:
-        raise subprocess.CalledProcessError(process.poll(), cmd, stderr=process.stderr)
+        raise subprocess.CalledProcessError(process.poll(), command, stderr=process.stderr)
     process.stderr.close()
